<?php
/**
 * Created by PhpStorm.
 * User: Andreu
 * Date: 10/05/2017
 * Time: 16:36
 */

namespace Intranet\DocenciaBundle\Controller;


use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Intranet\DocenciaBundle\Form\RespostaType;
use Intranet\IntranetBundle\Entity\Resposta;

class DocenciaAlumneController extends Controller
{
    /**
     * Aquesta funció carrega la vista de l'aula vista com un alumne
     * @param null $aula
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function iniciAction($aula = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $aulaSeleccionada = $em->getRepository('IntranetBundle:Aula')->find($aula);
        $publicacions = $em->getRepository('IntranetBundle:Publicacio')->findBy(array('aula'=>$aulaSeleccionada->getId()));
        return $this->render('DocenciaBundle:Default:inici_docencia_alumne.html.twig', array('usuari'=>$usuari, 'aula'=> $aulaSeleccionada, 'publicacions'=>$publicacions ));
    }

    /**
     * La funció crea un resposta en una aula vinculada a un apunt penjat prèviament per un professor
     * Un cop creada la resposta, envia una notificació a tots els alumnes de l'aula i al professor
     * @param Request $request
     * @param null $aula
     * @param null $publicacio
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function crearRespostaAction(Request $request, $aula = null, $publicacio = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $aulaSeleccionada = $em->getRepository('IntranetBundle:Aula')->find($aula);

        $resposta= new Resposta();
        $form = $this->createForm(RespostaType::class, $resposta);

        if($request->isMethod('POST')){
            $form->handleRequest($request);
            if($form->isValid()){

                $file = $form['arxiu']->getData();
                if(!empty($file) && $file != null){
                    $ext = $file ->guessExtension();
                    if($ext == 'jpg' || $ext == 'png' || $ext == 'jpeg' || $ext == 'gif' ){
                        $image_name= $usuari->getDni().time().".".$ext;
                        $file->move('uploads/apunts/documents', $image_name);
                        $resposta->setArxiu($image_name);


                    }else if($ext == 'pdf'){
                        $document_name= $usuari->getDni().time().".".$ext;
                        $file->move('uploads/apunts/documents', $document_name);
                        $resposta->setArxiu($document_name);

                    }else{
                        $resposta->setArxiu(null);
                    }
                }else{
                    $resposta->setArxiu(null);
                }
                $resposta->setAlumneCreador($usuari);
                $resposta->setPublicacioPare($em->getRepository('IntranetBundle:Publicacio')->find($publicacio));
                $resposta->setDataCreacio(new \DateTime("now"));
                $em->persist($resposta);
                $em->flush();


                $notificacio = $this->get('app.notificacio_service');
                $notificacio->setNotificacio($aulaSeleccionada->getProfessorResponsable(),'resposta_apunt',$usuari->getDni(),$aulaSeleccionada->getNom());
                foreach($aulaSeleccionada->getAlumnes() as $alumne){
                    $notificacio = $this->get('app.notificacio_service');
                    $notificacio->setNotificacio($alumne,'resposta_apunt',$usuari->getDni(),$aulaSeleccionada->getNom());
                }


                $publicacions = $em->getRepository('IntranetBundle:Publicacio')->findBy(array('aula'=>$aulaSeleccionada->getId()));
                return $this->render('DocenciaBundle:Default:inici_docencia_alumne.html.twig', array('usuari'=>$usuari, 'aula'=> $aulaSeleccionada, 'publicacions'=>$publicacions ));

            }else{
                return $this->render('DocenciaBundle:Default:crear_resposta_docencia_alumne.html.twig', array('usuari'=>$usuari, 'aula'=> $aulaSeleccionada, 'form'=>$form->createView() ));
            }
        }else{
            return $this->render('DocenciaBundle:Default:crear_resposta_docencia_alumne.html.twig', array('usuari'=>$usuari, 'aula'=> $aulaSeleccionada, 'form'=>$form->createView() ));
        }


    }

}