<?php

namespace Intranet\DocenciaBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Intranet\DocenciaBundle\Form\PublicacioType;
use Intranet\IntranetBundle\Entity\Publicacio;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;

class DocenciaProfessorController extends Controller
{
    /**
     * Aquesta funció carrega la vista de l'aula vista com un professor
     * @param null $aula
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function iniciAction($aula = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $aulaSeleccionada = $em->getRepository('IntranetBundle:Aula')->find($aula);
        $publicacions = $em->getRepository('IntranetBundle:Publicacio')->findBy(array('aula'=>$aulaSeleccionada->getId()));
        return $this->render('DocenciaBundle:Default:inici_docencia_professor.html.twig', array('usuari'=>$usuari, 'aula'=> $aulaSeleccionada, 'publicacions'=>$publicacions ));
    }

    /**
     * La funció crea un apunt en una aula creat per un professor
     * Un cop creat l'apunt, envia una notificació a tots els alumnes de l'aula
     * @param Request $request
     * @param null $aula
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function crearApuntAction(Request $request, $aula = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $aulaSeleccionada = $em->getRepository('IntranetBundle:Aula')->find($aula);

        $publicacio = new Publicacio();
        $form = $this->createForm(PublicacioType::class, $publicacio);

        if (!$request->isXmlHttpRequest()) {

            return $this->render('DocenciaBundle:Default:crear_apunt_docencia_professor.html.twig', array('usuari'=>$usuari, 'aula'=> $aulaSeleccionada, 'form'=>$form->createView() ));

        }else{
            $response = new JsonResponse();
            $response->setStatusCode(200);
            $form->handleRequest($request);

            if($form->isSubmitted()){

                if($form->isValid()){

                    $file = $form['arxiu']->getData();
                    if(!empty($file) && $file != null){
                        $ext = $file ->guessExtension();
                        if($ext == 'jpg' || $ext == 'png' || $ext == 'jpeg' || $ext == 'gif' ){
                            $image_name= $usuari->getDni().time().".".$ext;
                            $file->move('uploads/apunts/documents', $image_name);
                            $publicacio->setArxiu($image_name);


                        }else if($ext == 'pdf'){
                            $document_name= $usuari->getDni().time().".".$ext;
                            $file->move('uploads/apunts/documents', $document_name);
                            $publicacio->setArxiu($document_name);


                        }else{
                            $publicacio->setArxiu(null);
                        }
                    }else{
                        $publicacio->setArxiu(null);
                    }
                    $publicacio->setProfessor($usuari);
                    $publicacio->setAula($aulaSeleccionada);
                    $publicacio->setDataCreacio(new \DateTime("now"));
                    $em->persist($publicacio);
                    $em->flush();

                    foreach($aulaSeleccionada->getAlumnes() as $alumne){
                        $notificacio = $this->get('app.notificacio_service');
                        $notificacio->setNotificacio($alumne,'apunt',$usuari->getDni(),$aulaSeleccionada->getNom());
                    }

                    $response->setData(array(
                        'response' => 'success',
                    ));
                    return $response;
                }else{
                    $response->setData(array(
                        'response' => 'error',
                    ));
                    return $response;
                }
            }else{
                $response->setData(array(
                    'response' => 'error',
                ));
                return $response;
            }
        }


    }
}
