<?php

namespace Intranet\GestioAulesBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;
use Intranet\GestioAulesBundle\Form\CrearAulaType;
use Intranet\IntranetBundle\Entity\Aula;

class DefaultController extends Controller
{
    /**
     * Aquesta funció genera la vista amb tot el llistat d'aules creades
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function indexAction()
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $aules = $em->getRepository('IntranetBundle:Aula')->buscarTotesAules();
        return $this->render('GestioAulesBundle:Default:inici_gestio_aules.html.twig', array('usuari' => $usuari, 'aules'=>$aules));
    }

    /**
     * Funció que s'encarrega de generar el modal amb la informació de l'aula
     * @param Request $request
     * @param null $aula
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function retornarModalAction(Request $request, $aula = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();

        if (!$request->isXmlHttpRequest())
        {
            $aules = $em->getRepository('IntranetBundle:Aula')->buscarTotesAules();
            return $this->render('GestioAulesBundle:Default:inici_gestio_aules.html.twig', array('usuari' => $usuari, 'aules'=>$aules ));

        }else{

            $aula = $em->getRepository('IntranetBundle:Aula')->buscarAulaPerId($request->get('_id'));
            $alumnesNoInscrits = $em->getRepository('IntranetBundle:Usuari')->buscarAlumnesNoInscritsAula($aula);


            $response = new JsonResponse();
            $response->setStatusCode(200);

            $aules = array();

            foreach ($aula->getAlumnes() as $al){
                $aules [] = $al->__toString();
            }
            $response->setData(array(
                'response' => 'success',
                'nom' => $aula->getNom(),
                'descripcio' => $aula->getDescripcio() ,
                'professor' => $aula->getProfessorResponsable()->__toString() ,
                'gestor' => $aula->getGestorCreador()->__toString(),
                'alumnes' => $aules,
                'alumnesNoInscrits' => $alumnesNoInscrits
            ));
            return $response;
        }

    }

    /**
     * Funció que permet crear una aula.
     * Genera una notificació informant al professor a qui se li ha assignat l'aula.
     * @param Request $request
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function crearAulaAction(Request $request)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $aula = new Aula();
        $form = $this-> createForm(CrearAulaType::class, $aula, array(
            'empty_data' => $usuari
        ));

        if (!$request->isXmlHttpRequest())
        {
            return $this->render('GestioAulesBundle:Default:crear_gestio_aules.html.twig', array('usuari' => $usuari, 'form' =>$form->createView()));

        }else{
            $em = $this->getDoctrine()->getManager();
            $response = new JsonResponse();
            $response->setStatusCode(200);
            $form->handleRequest($request);
            if($form->isSubmitted()){
                if($form->isValid()){

                    $aula->setNom($form["nom"]->getData());
                    $aula->setDescripcio($form["descripcio"]->getData());
                    $aula->setGestorCreador($usuari);
                    $em->persist($aula);
                    $em->flush();

                    $notificacio = $this->get('app.notificacio_service');
                    $notificacio->setNotificacio($em->getRepository('IntranetBundle:Usuari')->find($form["professorResponsable"]->getData()->getDni()),'aula_creada',$usuari->getDni(),$form["nom"]->getData());

                    $response->setData(array(
                        'response' => 'success',
                    ));
                    return $response;

                }else{
                    die('entra');
                    $response->setData(array(
                        'response' => 'error',
                    ));
                    return $response;
                }
            }else{
                $response->setData(array(
                    'response' => 'error',
                ));
                return $response;
            }
        }

    }

    /**
     * Funció que permet inserir alumnes a una aula.
     * Genera una notificació a cada alumne inserit a l'aula.
     * @param Request $request
     * @param null $aula
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function inserirAlumnesAction(Request $request, $aula = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();

        if (!$request->isXmlHttpRequest())
        {
            $aules = $em->getRepository('IntranetBundle:Aula')->buscarTotesAules();
            return $this->render('GestioAulesBundle:Default:inici_gestio_aules.html.twig', array('usuari' => $usuari, 'aules'=>$aules ));
        }else{


            $alumnesAInserir = $request->get('selectmultiplealumnes');
            $aulaa = $em->getRepository('IntranetBundle:Aula')->buscarAulaPerId($aula);
            if(is_array($alumnesAInserir)){
                foreach ($alumnesAInserir as $alumneAInserir){
                    $usuariAula = $em->getRepository('IntranetBundle:Usuari')->buscarUsuariPelDni($alumneAInserir);
                    $aulaa->addAlumne($usuariAula);
                    $em->persist($aulaa);
                    $notificacio = $this->get('app.notificacio_service');
                    $notificacio->setNotificacio( $usuariAula ,'alumne_inserit',$usuari->getDni(),$aulaa->getNom());
                }
            }else{
                $usuariAula = $em->getRepository('IntranetBundle:Usuari')->buscarUsuariPelDni($alumnesAInserir);
                $aulaa->addAlumne($usuariAula);
                $em->persist($aulaa);
                $notificacio = $this->get('app.notificacio_service');
                $notificacio->setNotificacio($usuariAula,'alumne_inserit',$usuari->getDni(),$aulaa->getNom());
            }


            $em->flush();

            $response = new JsonResponse();
            $response->setStatusCode(200);
            $response->setData(array(
                'response' => 'success',
            ));
            return $response;
        }
    }
}
