<?php

namespace Intranet\GestioUsuarisBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;
use Intranet\GestioUsuarisBundle\Form\CrearUsuariType;
use Intranet\IntranetBundle\Entity\Usuari;

class DefaultController extends Controller
{
    /**
     * Carrega la vista amb el llistat amb tots els usuaris.
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function indexAction()
    {

        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $usuaris = $em->getRepository('IntranetBundle:Usuari')->buscarTotsElsUsuaris();

        return $this->render('GestioUsuarisBundle:Default:inici_gestio_usuaris.html.twig', array('usuari' => $usuari, 'usuaris'=> $usuaris));
    }

    /**
     * Funció que s'encarrega de generar el modal amb la informació de l'usuari
     * @param Request $request
     * @param null $user
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function retornarModalAction(Request $request, $user = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();

        if (!$request->isXmlHttpRequest())
        {
            $usuaris = $em->getRepository('IntranetBundle:Usuari')->buscarTotsElsUsuaris();
            return $this->render('GestioUsuarisBundle:Default:inici_gestio_usuaris.html.twig', array('usuari' => $usuari, 'usuaris'=> $usuaris));
        }else{
            $usuari = $em->getRepository('IntranetBundle:Usuari')->buscarUsuariPelDni($request->get('_dni'));
            $rolsNoDefinits = $em->getRepository('IntranetBundle:Rol')-> tornarRolsNoVinculatsUsuari($usuari->getRols());
            $response = new JsonResponse();
            $response->setStatusCode(200);

            $rolsNo = array();
            foreach ($rolsNoDefinits as $rol)
            {
                $rolsNo []= $rol->getRol();
            }

            $rols = array();
            foreach ($usuari->getRols() as $rol)
            {
                $rols[] = $rol->getRol();
            }

            $rol = $em->getRepository('IntranetBundle:Rol')->find('ROLE_GESTOR');


            $response->setData(array(
                'response' => 'success',
                'dni' => $usuari->getDni(),
                'nom' => $usuari->getNom() ,
                'cognom1' => $usuari->getCognom1() ,
                'cognom2' => $usuari->getCognom2(),
                'mail_extern' => $usuari->getMailExtern() ,
                'tlf' => $usuari->getTelefon(),
                'pais' =>  $usuari->getPais(),
                'ciutat' =>  $usuari->getCiutat(),
                'codi_postal' =>  $usuari->getCodiPostal(),
                'adressa' =>  $usuari->getDireccio(),
                'gustos' =>  $usuari->getBiografia(),
                'rols' => $rols,
                'rolsNoDefinits' => $rolsNo
            ));
            return $response;
        }

    }

    /**
     * Funció que permet eliminar un rol a un usuari.
     * Genera una notificació informant a l'usuari a qui se li ha eliminat el rol.
     * @param Request $request
     * @param null $user
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function eliminarRolUsuariAction(Request $request, $user=null)
    {

        $em = $this->getDoctrine()->getManager();
        $usuari = $this->get('security.token_storage')->getToken()->getUser();

        if (!$request->isXmlHttpRequest())
        {

            $usuaris = $em->getRepository('IntranetBundle:Usuari')->buscarTotsElsUsuaris();
            return $this->render('GestioUsuarisBundle:Default:inici_gestio_usuaris.html.twig', array('usuari' => $usuari, 'usuaris'=> $usuaris));
        }else {

            $rolAEliminar = $request->get('selectmultipledelete');
            $em->getRepository('IntranetBundle:Usuari')-> eliminarRolUsuari($user, $rolAEliminar);
            $rol_trobat = $em->getRepository('IntranetBundle:Rol')->find($rolAEliminar);

            //die(dump($usuari->getDni()));
            $notificacio = $this->get('app.notificacio_service');
            $notificacio->setNotificacio($em->getRepository('IntranetBundle:Usuari')->find($user),'rol_eliminat',$usuari->getDni(),$rol_trobat->getRol());

            $response = new JsonResponse();
            $response->setStatusCode(200);
            $response->setData(array(
                'response' => 'success',
            ));
            return $response;
        }
    }

    /**
     * Funció que permet inserir un rol a un usuari.
     * Genera una notificació informant a l'usuari a qui se li ha inserit el rol
     * @param Request $request
     * @param null $user
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function inserirRolUsuariAction(Request $request, $user = null)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();

        if (!$request->isXmlHttpRequest())
        {
            $usuaris = $em->getRepository('IntranetBundle:Usuari')->buscarTotsElsUsuaris();
            return $this->render('GestioUsuarisBundle:Default:inici_gestio_usuaris.html.twig', array('usuari' => $usuari, 'usuaris'=> $usuaris));
        }else{
            $rolAInserir = $request->get('selectmultipleinsert');
            $em->getRepository('IntranetBundle:Usuari')-> inserirRolUsuari($user, $rolAInserir);

            $rol_trobat = $em->getRepository('IntranetBundle:Rol')->find($rolAInserir);
            $notificacio = $this->get('app.notificacio_service');
            $notificacio->setNotificacio($em->getRepository('IntranetBundle:Usuari')->find($user),'rol_inserit',$usuari->getDni(),$rol_trobat->getRol());

            $response = new JsonResponse();
            $response->setStatusCode(200);
            $response->setData(array(
                'response' => 'success',
            ));
            return $response;
        }
    }

    /**
     * Funció que permet crear un nou usuari.
     * @param Request $request
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function crearUsuariAction(Request $request)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $form = $this-> createForm(CrearUsuariType::class);

        if (!$request->isXmlHttpRequest())
        {
            return $this->render('GestioUsuarisBundle:Default:crear_gestio_usuaris.html.twig', array('usuari' => $usuari, 'form' =>$form->createView()));

        }else{
            $em = $this->getDoctrine()->getManager();
            $response = new JsonResponse();
            $response->setStatusCode(200);
            $form->handleRequest($request);
            if($form->isSubmitted()){
                if($form->isValid()){

                    /*$em->getRepository('IntranetBundle:Usuari')->crearUsuari(
                        $form["dni"]->getData(),
                        $form["contrasenya"]->getData(),
                        $form["nom"]->getData(),
                        $form["cognom1"]->getData(),
                        $form["cognom2"]->getData(),
                        $form["mail_extern"]->getData(),
                        $form["telefon"]->getData(),
                        $form["direccio"]->getData(),
                        $form["codi_postal"]->getData(),
                        $form["ciutat"]->getData(),
                        $form["pais"]->getData()
                    );*/

                    $usuari = new Usuari();
                    $usuari->setDni($form["dni"]->getData());
                    $encoder = $this->container->get('security.password_encoder');
                    $encoded = $encoder->encodePassword($usuari, $form["contrasenya"]->getData());
                    $usuari->setContrasenya($encoded);
                    $usuari->setNom($form["nom"]->getData());
                    $usuari->setCognom1($form["cognom1"]->getData());
                    $usuari->setCognom2($form["cognom2"]->getData());
                    $usuari->setTelefon($form["telefon"]->getData());
                    $usuari->setDireccio($form["direccio"]->getData());
                    $usuari->setCodiPostal($form["codi_postal"]->getData());
                    $usuari->setCiutat($form["ciutat"]->getData());
                    $usuari->setPais($form["pais"]->getData());
                    $usuari->setBiografia('');
                    $usuari->setMailExtern($form["mail_extern"]->getData());
                    $rol  = $em->getRepository('IntranetBundle:Rol')->find('ROLE_USUARI');
                    $usuari->addRol($rol);
                    $em -> persist($usuari);
                    $em ->flush();

                    $response->setData(array(
                        'response' => 'success',
                    ));
                    return $response;

                }else{
                    $response->setData(array(
                        'response' => 'error',
                    ));
                    return $response;
                }
            }else{
                $response->setData(array(
                    'response' => 'error',
                ));
                return $response;
            }
        }




    }
}
