<?php
/**
 * Created by PhpStorm.
 * User: andreu-calvo
 * Date: 06/03/2017
 * Time: 13:42
 */
namespace Intranet\IntranetBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;
use Intranet\IntranetBundle\Form\PerfilType;
use Intranet\IntranetBundle\Form\MissatgeType;
use Intranet\IntranetBundle\Entity\Missatge;

class PortadaController extends Controller
{

    /**
     * Aquesta funció carrega la vista de la portada.
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function iniciAction()
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $aulesProfessor = $em->getRepository('IntranetBundle:Aula')->buscarAulesProfessor($usuari);
        $aulesAlumne =  $em->getRepository('IntranetBundle:Aula')->buscarAulesAlumne($usuari);
        return $this->render('IntranetBundle:Default:portada.html.twig', array('usuari' => $usuari, 'aulesProfessor'=>$aulesProfessor, 'aulesAlumne'=>$aulesAlumne));

    }

    /**
     * Aquesta funció carrega la vista del perfil. Retorna una resposta JSon quan aquest és modificat.
     * @param Request $request
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function perfilAction(Request $request)
    {
        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $imatge_usuari = $usuari->getImatge();
        $form = $this-> createForm(PerfilType::class, $usuari);

        if (!$request->isXmlHttpRequest())
        {

            return $this->render('IntranetBundle:Default:perfil.html.twig', array(
                'usuari' => $usuari,
                'form' => $form->createView()));
        }else{

            $em = $this->getDoctrine()->getManager();
            $response = new JsonResponse();
            $response->setStatusCode(200);

            $form->handleRequest($request);
            if($form->isSubmitted()){
                if($form->isValid()){

                    $file = $form["imatge"]->getData();

                    if(!empty($file) && $file != null){
                        $ext = $file->guessExtension();
                        if($ext == 'jpg' || $ext == 'jpeg' || $ext == 'png' || $ext == 'gif'){
                            $nom_file = $usuari->getDni().time().'.'.$ext;
                            $file->move("uploads/usuaris", $nom_file);
                            $usuari->setImatge($nom_file);
                            $em->persist($usuari);
                            $em->flush();
                        }
                    }else{
                        $usuari->setImatge($imatge_usuari);
                    }

                    $encoder = $this->container->get('security.password_encoder');
                    $encoded = $encoder->encodePassword($usuari,$form["contrasenya"]->getData());
                    $em->getRepository('IntranetBundle:Usuari')->actualizarUsuari(
                        $encoded,
                        $form["mail_extern"]->getData(),
                        $form["telefon"]->getData(),
                        $form["direccio"]->getData(),
                        $form["codi_postal"]->getData(),
                        $form["ciutat"]->getData(),
                        $form["pais"]->getData(),
                        $form["biografia"]->getData(),
                        $usuari->getDni()
                    );

                    $response->setData(array(
                        'response' => 'success',
                    ));
                    return $response;

                }else{
                    $response->setData(array(
                        'response' => 'error',
                    ));
                    return $response;
                }
            }else{
                $response->setData(array(
                    'response' => 'error',
                ));
                return $response;
            }
        }
    }

    /**
     * Aquesta funció carrega la vista de les notificacions.
     * @param Request $request
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function notificacioAction(Request $request){

        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $query_notificacions = $em->getRepository('IntranetBundle:Notificacio')->buscarNotificacionsUsuariQuery($usuari);

        $notificacio = $this->get('app.notificacio_service');
        $notificacio->llegida($usuari);

        $paginator = $this->get('knp_paginator');
        $notifications= $paginator->paginate($query_notificacions, $request->query->getInt('page',1), 5);

        return $this->render('IntranetBundle:Default:notificacions.html.twig', array('usuari'=> $usuari, 'pagination'=>$notifications ));
    }

    /**
     * Funció que es crida per comprovar si hi ha notificacions. Retorna un objecte JSON amb el número de notificacions pendents
     * @return JsonResponse
     */
    public function contarNotificacionsAction(){


        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $numero_notificacions = $em->getRepository('IntranetBundle:Notificacio')->buscarNumeroNotificacionsUsuariNoLlegides($usuari);

        $response = new JsonResponse();
        $response->setStatusCode(200);
        $response->setData(array(
            'response' => 'success',
            'num_notificacions' =>  $numero_notificacions[0]['1'],
        ));
        return $response;
    }

    /**
     * Funció que elimina una notificació.
     * @param Request $request
     * @return JsonResponse
     */
    public function eliminarNotificacionsAction(Request $request){
        $em = $this->getDoctrine()->getManager();

        $em->getRepository("IntranetBundle:Notificacio")->eliminarNotificacio($request->get('id'));

        $response = new JsonResponse();
        $response->setStatusCode(200);
        $response->setData(array(
            'response' => 'success',
        ));
        return $response;
    }

    /**
     * Carrega la vista amb el formulari per enviar missatges a altres usuaris.
     * A la vista també hi ha incorporat el llistat dels missatges rebuts, que han estat enviats per altres usuaris.
     * @param Request $request
     * @return JsonResponse|\Symfony\Component\HttpFoundation\Response
     */
    public function missatgeriaPrivadaAction(Request $request){
        $em = $this->getDoctrine()->getManager();
        $usuari = $this->get('security.token_storage')->getToken()->getUser();

        $missatge_privat = new Missatge();
        $form = $this->createForm(MissatgeType::class, $missatge_privat, array(
            'empty_data' => $usuari
        ));

        $missatges_rebuts = $em->getRepository('IntranetBundle:Missatge')->buscarMissatgesRebutsQuery($usuari);
        $paginator = $this->get('knp_paginator');
        $missatges_rebuts_pag= $paginator->paginate($missatges_rebuts, $request->query->getInt('page',1), 3);

        if (!$request->isXmlHttpRequest()) {

            return $this->render('IntranetBundle:Default:missatgeria.html.twig', array('usuari' => $usuari,'pagination'=>$missatges_rebuts_pag ,'form'=> $form->createView()));

        }else{
            if($request->get( 'page' ) != null){

                return $this->render ( 'IntranetBundle:Default:missatge_item.html.twig', array('pagination'=> $missatges_rebuts_pag));

            }elseif ($request->get( 'id' ) != null){

                $em->getRepository('IntranetBundle:Missatge')->marcarMissatgeComLlegit($request->get('id'));
                $missatges_rebuts = $em->getRepository('IntranetBundle:Missatge')->buscarMissatgesRebutsQuery($usuari);
                $missatges_rebuts_pag= $paginator->paginate($missatges_rebuts, $request->query->getInt('page',1), 3);

                return $this->render ( 'IntranetBundle:Default:missatge_item.html.twig', array('pagination'=> $missatges_rebuts_pag));

            } else{

                $response = new JsonResponse();
                $response->setStatusCode(200);

                $form->handleRequest($request);

                if($form->isSubmitted()){
                    if($form->isValid()){

                        $file = $form['arxiu']->getData();
                        if(!empty($file) && $file != null){
                            $ext = $file ->guessExtension();
                            if($ext == 'jpg' || $ext == 'png' || $ext == 'jpeg' || $ext == 'gif' ){
                                $image_name= $usuari->getDni().time().".".$ext;
                                $file->move('uploads/missatges/documents', $image_name);
                                $missatge_privat->setArxiu($image_name);


                            }else if($ext == 'pdf'){
                                $document_name= $usuari->getDni().time().".".$ext;
                                $file->move('uploads/missatges/documents', $document_name);
                                $missatge_privat->setArxiu($document_name);


                            }else{
                                $missatge_privat->setArxiu(null);
                            }
                        }else{
                            $missatge_privat->setArxiu(null);
                        }

                        $missatge_privat->setEmissor($usuari);
                        $missatge_privat->setDataCreacio(new \DateTime("now"));
                        $missatge_privat->setLlegit(0);
                        $em->persist($missatge_privat);
                        $em->flush();

                        $response->setData(array(
                            'response' => 'success',
                        ));
                        return $response;
                    }else{
                        $response->setData(array(
                            'response' => 'error',
                        ));
                        return $response;
                    }
                }else{
                    $response->setData(array(
                        'response' => 'error',
                    ));
                    return $response;
                }
            }

        }
    }

    /**
     * Carrega la vista amb tots els missatges que l'usuari ha enviat.
     * @param Request $request
     * @return \Symfony\Component\HttpFoundation\Response
     */
    public function missatgeriaEnviadaAction(Request $request){

        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $missatges_enviats = $em->getRepository('IntranetBundle:Missatge')->buscarMissatgesEnviatsQuery($usuari);

        $paginator = $this->get('knp_paginator');
        $missatges_enviats_pag= $paginator->paginate($missatges_enviats, $request->query->getInt('page',1), 5);

        return $this->render('IntranetBundle:Default:missatgeria_enviats.html.twig', array('usuari'=> $usuari, 'pagination'=>$missatges_enviats_pag ));
    }

    /**
     * Funció que es crida per comprovar si hi ha missatges no llegits. Retorna un objecte JSON amb el número de missatges pendents a llegir
     * @return JsonResponse
     */
    public function missatgeriaNoLlegidaAction(){

        $usuari = $this->get('security.token_storage')->getToken()->getUser();
        $em = $this->getDoctrine()->getManager();
        $num_missatges_no_llegits = $em->getRepository('IntranetBundle:Missatge')->buscarNumeroMissatgesNoLlegits($usuari);

        $response = new JsonResponse();
        $response->setStatusCode(200);
        $response->setData(array(
            'response' => 'success',
            'num_notificacions' =>  $num_missatges_no_llegits[0]['1'],
        ));
        return $response;
    }

}