<?php
/**
 * Created by PhpStorm.
 * User: andreu-calvo
 * Date: 07/03/2017
 * Time: 16:45
 */
namespace Intranet\IntranetBundle\Entity;

use Doctrine\ORM\EntityRepository;
use Symfony\Component\DependencyInjection\ContainerAwareInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class UsuariRepository extends  EntityRepository  implements  ContainerAwareInterface
{

    private $container;

    public function setContainer(ContainerInterface $container = null)
    {
        $this->container = $container;
    }

    public function buscarUsuariPelDni($dni){
        $em = $this->getEntityManager();
        $consulta = $em->createQuery('
            SELECT u FROM IntranetBundle:Usuari u
            WHERE u.dni = :dni');
        $consulta->setParameter('dni', $dni);
        return $consulta->getOneOrNullResult();
    }

    public function buscarTotsElsUsuaris(){
        $em = $this->getEntityManager();
        $consulta = $em->createQuery('
            SELECT u FROM IntranetBundle:Usuari u
            ORDER BY u.nom
        ');
        return $consulta->getResult();
    }

    public function buscarProfessors(){
        $em = $this->getEntityManager();
        $consulta = $em -> createQuery('
            SELECT u FROM IntranetBundle:Usuari u
            INNER JOIN u.rols r
            WHERE r.rol = :rol
        ');
        $consulta ->setParameter('rol', 'ROLE_PROFESSOR');
        return $consulta->getResult();
    }

    public function actualizarUsuari($contrasenya, $email, $tlf,  $adressa, $codi_postal, $ciutat, $pais, $gustos, $dni)
    {
        $em = $this->getEntityManager();
        $consulta = $em->createQuery('
            UPDATE IntranetBundle:Usuari u 
            SET u.contrasenya = :contrasenya,
            u.mail_extern = :email,
            u.telefon = :tlf,
            u.direccio = :adressa,
            u.codi_postal = :codi_postal,
            u.ciutat = :ciutat,
            u.pais = :pais,
            u.biografia = :gustos
            WHERE u.dni = :dni
        ');
        $consulta->setParameter('contrasenya',$contrasenya);
        $consulta->setParameter('email',$email);
        $consulta->setParameter('tlf', $tlf);
        $consulta->setParameter('adressa', $adressa);
        $consulta->setParameter('codi_postal', $codi_postal);
        $consulta->setParameter('ciutat', $ciutat);
        $consulta->setParameter('pais',$pais);
        $consulta->setParameter('gustos',$gustos);
        $consulta->setParameter('dni',$dni);

        $consulta->execute();
    }

    public function inserirRolUsuari($dni, $rol)
    {
        $em = $this->getEntityManager();
        $entitat = $em->getRepository('IntranetBundle:Usuari')->buscarUsuariPelDni($dni);
        $rol_trobat = $em->getRepository('IntranetBundle:Rol')->find($rol);
        $entitat -> addRol($rol_trobat);
        $em -> persist($entitat);
        $em ->flush();
    }

    public function eliminarRolUsuari($dni, $rol)
    {
        $em = $this->getEntityManager();
        $entitat = $em->getRepository('IntranetBundle:Usuari')->buscarUsuariPelDni($dni);
        $rol_trobat = $em->getRepository('IntranetBundle:Rol')->find($rol);
        $entitat -> removeRol($rol_trobat);
        $em -> persist($entitat);
        $em ->flush();
    }

    public function crearUsuari($dni ,$contrasenya, $nom, $congom1, $cognom2, $email, $tlf,  $adressa, $codi_postal, $ciutat, $pais){
        $em = $this->getEntityManager();
        $usuari = new Usuari();
        $usuari->setDni($dni);
        $encoder = $this->container->get('security.password_encoder');
        $encoded = $encoder->encodePassword($usuari, $contrasenya);
        $usuari->setContrasenya($encoded);
        $usuari->setNom($nom);
        $usuari->setCognom1($congom1);
        $usuari->setCognom2($cognom2);
        $usuari->setTelefon($tlf);
        $usuari->setDireccio($adressa);
        $usuari->setCodiPostal($codi_postal);
        $usuari->setCiutat($ciutat);
        $usuari->setPais($pais);
        $usuari->setBiografia('');
        $usuari->setMailExtern($email);
        $rol  = $em->getRepository('IntranetBundle:Rol')->find('ROLE_USUARI');
        $usuari->addRol($rol);
        $em -> persist($usuari);
        $em ->flush();
    }

    public function buscarAdministradors(){
        $em = $this->getEntityManager();
        $consulta = $em -> createQuery('
            SELECT u FROM IntranetBundle:Usuari u
            INNER JOIN u.rols r
            WHERE r.rol = :rol
        ');
        $consulta ->setParameter('rol', 'ROLE_ADMINISTRADOR');
        return $consulta->getResult();
    }

    public function buscarAlumnesNoInscritsAula($aula){
        $em = $this->getEntityManager();
        /*$consulta = $em -> createQuery('
            SELECT u.dni, u.nom, u.cognom1, u.cognom2  FROM IntranetBundle:Usuari u
            INNER JOIN u.rols r
            WHERE r.rol = :rol
            AND u.dni != (
              SELECT al.dni FROM IntranetBundle:Aula a
              INNER JOIN a.alumnes al
              WHERE a.id = :id
            )
        ');*/
        $consulta = $em -> createQuery('
            SELECT u.dni, u.nom, u.cognom1, u.cognom2 FROM IntranetBundle:Usuari u
            INNER JOIN u.rols r
            WHERE r.rol = :rol
          
        ');
        $consulta ->setParameter('rol', 'ROLE_ALUMNE');
        //$consulta->setParameter('id', $aula->getId());
        return $consulta->getResult();
    }



}